compilers_ = {
    "python": "cpython-head",
    "c++": "gcc-head",
    "cpp": "gcc-head",
    "c": "gcc-head",
    "javascript": "nodejs-head",
    "js": "nodejs-head",
    "coffeescript": "coffeescript-head",
    "cs": "coffeescript-head",
    "java": "openjdk-head",
    "haskell": "ghc-8.4.2",
    "bash": "bash",
    "cmake": "cmake-head",
    "crystal": "crystal-head",
    "elixir": "elixir-head",
    "d": "dmd-head",
    "ruby": "ruby-head",
    "rust": "rust-head",
    "sql": "sqlite-head",
    "sqlite": "sqlite-head",
    "lisp": "clisp-2.49",
    "go": "go-head",
    "f#": "fsharp-head",
    "scala": "scala-2.13.x",
    "swift": "swift-head",
    "typescript": "typescript-3.9.5",
    "ts": "typescript-3.9.5",
    "vim": "vim-head",
    "lua": "lua-5.4.0",
    "nim": "nim-head",
    "php": "php-head",
    "perl": "perl-head",
    "pony": "pony-head",
}
